@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.13'
+__version__ = '0.2.14'
 
 __all__ = [
     'ANY_BOOLEAN',
@@ -46,6 +46,7 @@ except ImportError as import_error:
     print('Please install importlib using "pip install importlib".')
 
 from mock import Mock, call, patch
+
 from logging import getLogger
 from unittest import TestCase
 from types import ModuleType
@@ -187,6 +188,9 @@ class FluentCallEntry(object):
                 if isinstance(self.keyword_arguments[key], FluentMatcher):
                     if not self.keyword_arguments[key].matches(keyword_arguments[key]):
                         return False
+                elif isinstance(keyword_arguments[key], FluentMatcher):
+                    if not keyword_arguments[key].matches(self.keyword_arguments[key]):
+                        return False
                 elif self.keyword_arguments[key] != keyword_arguments[key]:
                     return False
 
